@@ -1,5 +1,5 @@
 package Math::KullbackLeibler::Discrete;
-
+$Math::KullbackLeibler::Discrete::VERSION = '0.07';
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
@@ -7,60 +7,6 @@ use parent 'Exporter';
 
 our @EXPORT = qw(kl);
 
-=encoding utf-8
-
-=head1 NAME
-
-Math::KullbackLeibler::Discrete - Computes Kullback-Leibler divergence for two discrete distributes.
-
-=head1 VERSION
-
-Version 0.05
-
-=cut
-
-our $VERSION = '0.06';
-
-
-=head1 SYNOPSIS
-
-This module computes Kullback-Leibler divergence for two discrete
-distributions, using smoothing.
-
-    use Math::KullbackLeibler::Discrete;
-
-    my $P = { a => 1/2, b => 1/4, c => 1/4 };
-    my $Q = { a => 7/12, b => 2/12, d => 3/12 };
-
-    my $kl = kl( $P, $Q );
-
-    # optionally set the smoothing epsilon
-    my $kl2 = kl( $P, $Q, epsilon => 0.0001 );
-
-    # setting epsilon to 0 results in no smoothing.
-    my $kl3 = kl( $P, $Q, epsilon => 0 );
-
-=head1 EXPORT
-
-=head2 kl
-
-Computes smoothed KL.
-
-Receives two mandatory arguments: two anonymous hashrefs, that map
-events to their probabilities.
-
-Implementation based on the description presented at
-L<http://www.cs.bgu.ac.il/~elhadad/nlp09/KL.html>.
-
-The smoothing amount can be specified as parameter:
-
-   kl( $P, $Q, epsilon => 0.001 );
-
-This makes it possible to turn of smoothing, defined epsilon as
-zero. However, notice that this will lead to errors in case of
-divergent domains.
-
-=cut
 
 sub kl {
     my ($P, $Q, %opts) = @_;
@@ -99,6 +45,65 @@ sub kl {
     return $kl;
 }
 
+
+1; # End of Math::KullbackLeibler::Discrete
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Math::KullbackLeibler::Discrete
+
+=head1 VERSION
+
+version 0.07
+
+=head1 SYNOPSIS
+
+This module computes Kullback-Leibler divergence for two discrete
+distributions, using smoothing.
+
+    use Math::KullbackLeibler::Discrete;
+
+    my $P = { a => 1/2, b => 1/4, c => 1/4 };
+    my $Q = { a => 7/12, b => 2/12, d => 3/12 };
+
+    my $kl = kl( $P, $Q );
+
+    # optionally set the smoothing epsilon
+    my $kl2 = kl( $P, $Q, epsilon => 0.0001 );
+
+    # setting epsilon to 0 results in no smoothing.
+    my $kl3 = kl( $P, $Q, epsilon => 0 );
+
+=head1 NAME
+
+Math::KullbackLeibler::Discrete - Computes Kullback-Leibler divergence for two discrete distributes.
+
+=head1 EXPORT
+
+=head2 kl
+
+Computes smoothed KL.
+
+Receives two mandatory arguments: two anonymous hashrefs, that map
+events to their probabilities.
+
+Implementation based on the description presented at
+L<http://www.cs.bgu.ac.il/~elhadad/nlp09/KL.html>.
+
+The smoothing amount can be specified as parameter:
+
+   kl( $P, $Q, epsilon => 0.001 );
+
+This makes it possible to turn of smoothing, defined epsilon as
+zero. However, notice that this will lead to errors in case of
+divergent domains.
+
 =head1 AUTHOR
 
 Alberto Simoes, C<< <ambs at cpan.org> >>
@@ -115,7 +120,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Math::KullbackLeibler::Discrete
 
-
 You can also look for information at:
 
 =over 4
@@ -138,7 +142,6 @@ L<http://search.cpan.org/dist/Math-KullbackLeibler-Discrete/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
 Thanks to Michael Elhadad for making his lecture on-line, so I found a
@@ -185,7 +188,15 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=head1 AUTHOR
+
+Alberto Simões <ambs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Alberto Simões.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1; # End of Math::KullbackLeibler::Discrete
